#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <limits.h>
#include <string.h>

/* we solve this problem by constructing a graph where the nodes are the
 * configurations of switches, and following an edge means flipping a switch
 * the nodes are labelled with integers whose binary representation gives
 * the switch values.  E.g. node 13 means 1101 which means on-on-off-on */

/* no edge connecting two nodes */
#define NO_EDGE INT_MAX

/* get configuration from starting point based on switch pulled */
int next_config(int switches, int config, int which) {
    /* we need to flip bit "which" inside config */
    int next = config ^ (1 << which);

    /* if not on left edge, flip the left switch too */
    if (which < (switches - 1)) {
        next ^= (1 << (which + 1));
    }

    /* if not on right edge, flip right switch too */
    if (which > 0) {
        next ^= (1 << (which - 1));
    }

    return next;
}

/* this function builds the graph based on flipping the switches */
void build_graph(int** matrix, int switches, int nodes) {
    /* for each possible configuration */
    for (int node = 0; node < nodes; node++) {
        /* for each switch which can be flipped */
        for (int switchy = 0; switchy < switches; switchy++) {
            /* find the configuration this would take us to */
            int next = next_config(switches, node, switchy);

            /* insert this connection into graph */
            matrix[node][next] = 1;
        }
    }
}

/* perform Dijkstra's shortest path algorithm */
int shortestPath(int** matrix, int nodes, int start) {
    /* we want to go to last config (all 1's) */
    int end = nodes - 1;

    /* make array of tentative costs, set all as no edge, except start */
    int* tentative = malloc(nodes * sizeof(int));
    for (int i = 0; i < nodes; i++) {
        tentative[i] = NO_EDGE;
    }
    tentative[start] = 0;

    /* make an array of which nodes we've hit */
    int* visited = malloc(nodes * sizeof(int));
    for (int i = 0; i < nodes; i++) {
        visited[i] = 0;
    }

    /* start at the beginning */
    int current = start;

    while (current != -1) {
        /* for each possible neighbor */
        for (int i = 0; i < nodes; i++) {
            if (matrix[current][i] != NO_EDGE) {
                /* if going through this node is cheaper, do it */
                int distance = tentative[current] + matrix[current][i];
                if (distance < tentative[i]) {
                    tentative[i] = distance;
                    visited[i] = 0;
                }
            }
        }

        /* mark this node as visited */
        visited[current] = 1;

        /* move to the next node */
        int min = 10 * nodes;
        current = -1;
        for (int i = 0; i < nodes; i++) {
            if (!visited[i] && (tentative[i] < min)) {
                min = tentative[i];
                current = i;
            }
        }
    }

    /* clean up after ourselves */
    free(tentative);
    free(visited);

    /* return tentative cost (which is now minimal) to destination */
    return tentative[end]; 
}

int main() {
    /* get number of switches */
    int switches, nodes;
    scanf("%d", &switches);
    nodes = pow(2, switches);

    /* initialize the graph */
    int** matrix = malloc(nodes * sizeof(int*));
    for (int i = 0; i < nodes; i++) {
        matrix[i] = malloc(nodes * sizeof(int));
        for (int j = 0; j < nodes; j++) {
            matrix[i][j] = NO_EDGE;
        }
    }

    /* build the graph's edges based on size */
    build_graph(matrix, switches, nodes);

    /* read the initial configuration */
    int initial = 0;
    for (int i = switches - 1; i >= 0; i--) {
        char position[5];
        scanf("%s", position);
        if (strcmp(position, "On") == 0) {
            initial |= (1 << i);
        }
    }

    /* find the cost of the path from this config to final one */
    unsigned int cost = shortestPath(matrix, nodes, initial);

    /* print the cost, or impossible */
    if (cost < NO_EDGE) {
        printf("Link must pull %d switches.\n", cost);
    } else {
        printf("There is no solution.\n");
    }

    /* free memory we used */
    for (int i = 0; i < nodes; i++) {
        free(matrix[i]);
    }
    free(matrix);

    return 0;
}

